@@ -446,9 +446,9 @@ def remove_cte(part, as_string=False):
             sp = helper.try_decode(bp)
         except UnicodeDecodeError as emsg:
             # the mail contains chars that are not enc-encoded.
-            # libmagic works better than just ignoring those
+            # try again and just ignore those
             logging.debug('Decoding failure: {}'.format(emsg))
-            sp = helper.try_decode(bp)
+            sp = bp.decode(enc, errors='ignore')
         return sp
     return bp
 
